# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: consensus.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'consensus.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63onsensus.proto\x12\x12omium.consensus.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x9b\x02\n\x10\x43onsensusMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\x12\x0c\n\x04term\x18\x03 \x01(\x03\x12\x11\n\tlog_index\x18\x04 \x01(\x03\x12\x17\n\x0fsender_agent_id\x18\x05 \x01(\t\x12\x1a\n\x12receiver_agent_ids\x18\x06 \x03(\t\x12\x35\n\x0cmessage_type\x18\x07 \x01(\x0e\x32\x1f.omium.consensus.v1.MessageType\x12(\n\x07payload\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf5\x01\n\x17\x42roadcastMessageRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x17\n\x0fsender_agent_id\x18\x02 \x01(\t\x12\x1a\n\x12receiver_agent_ids\x18\x03 \x03(\t\x12\x35\n\x0cmessage_type\x18\x04 \x01(\x0e\x32\x1f.omium.consensus.v1.MessageType\x12(\n\x07payload\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\racks_required\x18\x06 \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\x07 \x01(\x03\"\xdb\x01\n\x18\x42roadcastMessageResponse\x12\x35\n\x07message\x18\x01 \x01(\x0b\x32$.omium.consensus.v1.ConsensusMessage\x12\x19\n\x11\x63onsensus_reached\x18\x02 \x01(\x08\x12\x15\n\racks_received\x18\x03 \x01(\x05\x12\x15\n\racks_required\x18\x04 \x01(\x05\x12\x17\n\x0f\x61\x63knowledged_by\x18\x05 \x03(\t\x12\x0f\n\x07success\x18\x06 \x01(\x08\x12\x15\n\rerror_message\x18\x07 \x01(\t\"g\n\x19\x41\x63knowledgeMessageRequest\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12\r\n\x05valid\x18\x03 \x01(\x08\x12\x15\n\rerror_message\x18\x04 \x01(\t\"_\n\x1a\x41\x63knowledgeMessageResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x19\n\x11\x63onsensus_reached\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"E\n\x19GetConsensusStatusRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x12\n\nmessage_id\x18\x02 \x01(\t\"\xb7\x02\n\x1aGetConsensusStatusResponse\x12\x35\n\x07message\x18\x01 \x01(\x0b\x32$.omium.consensus.v1.ConsensusMessage\x12\x19\n\x11\x63onsensus_reached\x18\x02 \x01(\x08\x12\x15\n\racks_received\x18\x03 \x01(\x05\x12\x15\n\racks_required\x18\x04 \x01(\x05\x12\x17\n\x0f\x61\x63knowledged_by\x18\x05 \x03(\t\x12\x16\n\x0epending_agents\x18\x06 \x03(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14\x63onsensus_reached_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe2\x01\n\x0fHandoffProposal\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\x12\x15\n\rfrom_agent_id\x18\x03 \x01(\t\x12\x13\n\x0bto_agent_id\x18\x04 \x01(\t\x12&\n\x05state\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07\x63ontext\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12/\n\x0bproposed_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xab\x01\n\x15ProposeHandoffRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x15\n\rfrom_agent_id\x18\x02 \x01(\t\x12\x13\n\x0bto_agent_id\x18\x03 \x01(\t\x12&\n\x05state\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07\x63ontext\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"w\n\x16ProposeHandoffResponse\x12\x35\n\x08proposal\x18\x01 \x01(\x0b\x32#.omium.consensus.v1.HandoffProposal\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"[\n\x14VoteOnHandoffRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12\x0c\n\x04vote\x18\x03 \x01(\x08\x12\x0e\n\x06reason\x18\x04 \x01(\t\"\x9c\x01\n\x15VoteOnHandoffResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x19\n\x11proposal_accepted\x18\x02 \x01(\x08\x12\x11\n\tvotes_for\x18\x03 \x01(\x05\x12\x15\n\rvotes_against\x18\x04 \x01(\x05\x12\x16\n\x0evotes_required\x18\x05 \x01(\x05\x12\x15\n\rerror_message\x18\x06 \x01(\t*\x9b\x01\n\x0bMessageType\x12\x1c\n\x18MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14MESSAGE_TYPE_HANDOFF\x10\x01\x12\x1d\n\x19MESSAGE_TYPE_STATE_UPDATE\x10\x02\x12\x1b\n\x17MESSAGE_TYPE_COMPLETION\x10\x03\x12\x18\n\x14MESSAGE_TYPE_FAILURE\x10\x04\x32\xba\x04\n\x10\x43onsensusService\x12m\n\x10\x42roadcastMessage\x12+.omium.consensus.v1.BroadcastMessageRequest\x1a,.omium.consensus.v1.BroadcastMessageResponse\x12s\n\x12\x41\x63knowledgeMessage\x12-.omium.consensus.v1.AcknowledgeMessageRequest\x1a..omium.consensus.v1.AcknowledgeMessageResponse\x12s\n\x12GetConsensusStatus\x12-.omium.consensus.v1.GetConsensusStatusRequest\x1a..omium.consensus.v1.GetConsensusStatusResponse\x12g\n\x0eProposeHandoff\x12).omium.consensus.v1.ProposeHandoffRequest\x1a*.omium.consensus.v1.ProposeHandoffResponse\x12\x64\n\rVoteOnHandoff\x12(.omium.consensus.v1.VoteOnHandoffRequest\x1a).omium.consensus.v1.VoteOnHandoffResponseB5Z3github.com/omium/shared/proto/consensus;consensuspbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'consensus_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/omium/shared/proto/consensus;consensuspb'
  _globals['_MESSAGETYPE']._serialized_start=2222
  _globals['_MESSAGETYPE']._serialized_end=2377
  _globals['_CONSENSUSMESSAGE']._serialized_start=103
  _globals['_CONSENSUSMESSAGE']._serialized_end=386
  _globals['_BROADCASTMESSAGEREQUEST']._serialized_start=389
  _globals['_BROADCASTMESSAGEREQUEST']._serialized_end=634
  _globals['_BROADCASTMESSAGERESPONSE']._serialized_start=637
  _globals['_BROADCASTMESSAGERESPONSE']._serialized_end=856
  _globals['_ACKNOWLEDGEMESSAGEREQUEST']._serialized_start=858
  _globals['_ACKNOWLEDGEMESSAGEREQUEST']._serialized_end=961
  _globals['_ACKNOWLEDGEMESSAGERESPONSE']._serialized_start=963
  _globals['_ACKNOWLEDGEMESSAGERESPONSE']._serialized_end=1058
  _globals['_GETCONSENSUSSTATUSREQUEST']._serialized_start=1060
  _globals['_GETCONSENSUSSTATUSREQUEST']._serialized_end=1129
  _globals['_GETCONSENSUSSTATUSRESPONSE']._serialized_start=1132
  _globals['_GETCONSENSUSSTATUSRESPONSE']._serialized_end=1443
  _globals['_HANDOFFPROPOSAL']._serialized_start=1446
  _globals['_HANDOFFPROPOSAL']._serialized_end=1672
  _globals['_PROPOSEHANDOFFREQUEST']._serialized_start=1675
  _globals['_PROPOSEHANDOFFREQUEST']._serialized_end=1846
  _globals['_PROPOSEHANDOFFRESPONSE']._serialized_start=1848
  _globals['_PROPOSEHANDOFFRESPONSE']._serialized_end=1967
  _globals['_VOTEONHANDOFFREQUEST']._serialized_start=1969
  _globals['_VOTEONHANDOFFREQUEST']._serialized_end=2060
  _globals['_VOTEONHANDOFFRESPONSE']._serialized_start=2063
  _globals['_VOTEONHANDOFFRESPONSE']._serialized_end=2219
  _globals['_CONSENSUSSERVICE']._serialized_start=2380
  _globals['_CONSENSUSSERVICE']._serialized_end=2950
# @@protoc_insertion_point(module_scope)
