# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tracing.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tracing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rtracing.proto\x12\x10omium.tracing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xe1\x02\n\x0fSaveSpanRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08trace_id\x18\x02 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0cservice_name\x18\x05 \x01(\t\x12.\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64uration_ms\x18\x08 \x01(\x03\x12+\n\nattributes\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x06\x65vents\x18\n \x03(\x0b\x32\x1c.omium.tracing.v1.TraceEvent\x12\x0e\n\x06status\x18\x0b \x01(\t\x12\x16\n\x0estatus_message\x18\x0c \x01(\t\"v\n\nTraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\nattributes\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\":\n\x10SaveSpanResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"#\n\x0fGetTraceRequest\x12\x10\n\x08trace_id\x18\x01 \x01(\t\"b\n\x10GetTraceResponse\x12&\n\x05trace\x18\x01 \x01(\x0b\x32\x17.omium.tracing.v1.Trace\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"\xda\x01\n\x05Trace\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\x12\x10\n\x08trace_id\x18\x03 \x01(\t\x12*\n\x05spans\x18\x04 \x03(\x0b\x32\x1b.omium.tracing.v1.TraceSpan\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64uration_ms\x18\x07 \x01(\x03\"\xdb\x02\n\tTraceSpan\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08trace_id\x18\x02 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0cservice_name\x18\x05 \x01(\t\x12.\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64uration_ms\x18\x08 \x01(\x03\x12+\n\nattributes\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x06\x65vents\x18\n \x03(\x0b\x32\x1c.omium.tracing.v1.TraceEvent\x12\x0e\n\x06status\x18\x0b \x01(\t\x12\x16\n\x0estatus_message\x18\x0c \x01(\t\"H\n\x11ListTracesRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\"e\n\x12ListTracesResponse\x12\'\n\x06traces\x18\x01 \x03(\x0b\x32\x17.omium.tracing.v1.Trace\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"3\n\x1b\x42uildDependencyGraphRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"x\n\x1c\x42uildDependencyGraphResponse\x12\x30\n\x05graph\x18\x01 \x01(\x0b\x32!.omium.tracing.v1.DependencyGraph\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"i\n\x0f\x44\x65pendencyGraph\x12*\n\x05nodes\x18\x01 \x03(\x0b\x32\x1b.omium.tracing.v1.GraphNode\x12*\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\x1b.omium.tracing.v1.GraphEdge\"%\n\tGraphNode\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"3\n\tGraphEdge\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t2\x86\x03\n\x0eTracingService\x12Q\n\x08SaveSpan\x12!.omium.tracing.v1.SaveSpanRequest\x1a\".omium.tracing.v1.SaveSpanResponse\x12Q\n\x08GetTrace\x12!.omium.tracing.v1.GetTraceRequest\x1a\".omium.tracing.v1.GetTraceResponse\x12W\n\nListTraces\x12#.omium.tracing.v1.ListTracesRequest\x1a$.omium.tracing.v1.ListTracesResponse\x12u\n\x14\x42uildDependencyGraph\x12-.omium.tracing.v1.BuildDependencyGraphRequest\x1a..omium.tracing.v1.BuildDependencyGraphResponseBEZCgithub.com/omium/tracing-service/internal/proto/generated;tracingpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tracing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/omium/tracing-service/internal/proto/generated;tracingpb'
  _globals['_SAVESPANREQUEST']._serialized_start=99
  _globals['_SAVESPANREQUEST']._serialized_end=452
  _globals['_TRACEEVENT']._serialized_start=454
  _globals['_TRACEEVENT']._serialized_end=572
  _globals['_SAVESPANRESPONSE']._serialized_start=574
  _globals['_SAVESPANRESPONSE']._serialized_end=632
  _globals['_GETTRACEREQUEST']._serialized_start=634
  _globals['_GETTRACEREQUEST']._serialized_end=669
  _globals['_GETTRACERESPONSE']._serialized_start=671
  _globals['_GETTRACERESPONSE']._serialized_end=769
  _globals['_TRACE']._serialized_start=772
  _globals['_TRACE']._serialized_end=990
  _globals['_TRACESPAN']._serialized_start=993
  _globals['_TRACESPAN']._serialized_end=1340
  _globals['_LISTTRACESREQUEST']._serialized_start=1342
  _globals['_LISTTRACESREQUEST']._serialized_end=1414
  _globals['_LISTTRACESRESPONSE']._serialized_start=1416
  _globals['_LISTTRACESRESPONSE']._serialized_end=1517
  _globals['_BUILDDEPENDENCYGRAPHREQUEST']._serialized_start=1519
  _globals['_BUILDDEPENDENCYGRAPHREQUEST']._serialized_end=1570
  _globals['_BUILDDEPENDENCYGRAPHRESPONSE']._serialized_start=1572
  _globals['_BUILDDEPENDENCYGRAPHRESPONSE']._serialized_end=1692
  _globals['_DEPENDENCYGRAPH']._serialized_start=1694
  _globals['_DEPENDENCYGRAPH']._serialized_end=1799
  _globals['_GRAPHNODE']._serialized_start=1801
  _globals['_GRAPHNODE']._serialized_end=1838
  _globals['_GRAPHEDGE']._serialized_start=1840
  _globals['_GRAPHEDGE']._serialized_end=1891
  _globals['_TRACINGSERVICE']._serialized_start=1894
  _globals['_TRACINGSERVICE']._serialized_end=2284
# @@protoc_insertion_point(module_scope)
